AMPLFI
======
**Accelerated Multi-messenger Parameter estimation with Likelihood Free Inference**

Framework for performing rapid (~ 1s) parameter estimation of gravitational wave events using likelihood free inference.

```{eval-rst}
.. toctree::
   :caption: Getting started
   :maxdepth: 1

   Installation <installation>
   First pipeline <first_pipeline>
   Contributing <contributing>
   amplfi

.. toctree::
   :caption: Advanced
   :maxdepth: 1

   Running in containers <containers>
   Remote Training <remote_training>
   Hyperparameter Tuning <tuning>
```

Please cite https://arxiv.org/abs/2407.19048 if you have benefited from `AMPLFI` in your work
